@@ -1,6 +1,7 @@
 // SPDX-FileCopyrightText: 2023 James Graham <james.h.graham@protonmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
+#include <Quotient/events/event.h>
 #include <Quotient/syncdata.h>
 
 #include "neochatroom.h"
@@ -38,4 +39,17 @@ public:
         }
     }
 };
+
+template<Quotient::EventClass EventT>
+inline Quotient::event_ptr_tt<EventT> loadEventFromFile(const QString &eventFileName)
+{
+    if (!eventFileName.isEmpty()) {
+        QFile testEventFile;
+        testEventFile.setFileName(QLatin1String(DATA_DIR) + u'/' + eventFileName);
+        testEventFile.open(QIODevice::ReadOnly);
+        auto testSyncJson = QJsonDocument::fromJson(testEventFile.readAll()).object();
+        return Quotient::loadEvent<EventT>(testSyncJson);
+    }
+    return nullptr;
+}
 }
