@@ -64,7 +64,11 @@ Controller::Controller(QObject *parent)
         });
     } else {
         auto c = new NeoChatConnection(this);
+#if Quotient_VERSION_MINOR > 8
+        c->assumeIdentity(QStringLiteral("@user:localhost:1234"), QStringLiteral("device_1234"), QStringLiteral("token_1234"));
+#else
         c->assumeIdentity(QStringLiteral("@user:localhost:1234"), QStringLiteral("token_1234"));
+#endif
         connect(c, &Connection::connected, this, [c, this]() {
             m_accountRegistry.add(c);
             c->syncLoop();
@@ -202,15 +206,33 @@ void Controller::invokeLogin()
                 m_connectionsLoading[accountId] = connection;
                 connect(connection, &NeoChatConnection::connected, this, [this, connection, accountId] {
                     connection->loadState();
-                    addConnection(connection);
-                    m_accountsLoading.removeAll(connection->userId());
-                    m_connectionsLoading.remove(accountId);
-                    Q_EMIT accountsLoadingChanged();
+                    if (connection->allRooms().size() == 0 || connection->allRooms()[0]->currentState().get<RoomCreateEvent>()) {
+                        addConnection(connection);
+                        m_accountsLoading.removeAll(connection->userId());
+                        m_connectionsLoading.remove(accountId);
+                        Q_EMIT accountsLoadingChanged();
+                    } else {
+                        connect(
+                            connection->allRooms()[0],
+                            &Room::baseStateLoaded,
+                            this,
+                            [this, connection, accountId]() {
+                                addConnection(connection);
+                                m_accountsLoading.removeAll(connection->userId());
+                                m_connectionsLoading.remove(accountId);
+                                Q_EMIT accountsLoadingChanged();
+                            },
+                            Qt::SingleShotConnection);
+                    }
                 });
                 connect(connection, &NeoChatConnection::networkError, this, [this](const QString &error, const QString &, int, int) {
                     Q_EMIT errorOccured(i18n("Network Error: %1", error), {});
                 });
+#if Quotient_VERSION_MINOR > 8
+                connection->assumeIdentity(account.userId(), account.deviceId(), accessToken);
+#else
                 connection->assumeIdentity(account.userId(), accessToken);
+#endif
             });
         }
     }
@@ -251,23 +273,19 @@ QKeychain::ReadPasswordJob *Controller::loadAccessTokenFromKeyChain(const QStrin
     return job;
 }
 
-bool Controller::saveAccessTokenToKeyChain(const QString &userId, const QByteArray &accessToken)
+void Controller::saveAccessTokenToKeyChain(const QString &userId, const QByteArray &accessToken)
 {
     qDebug() << "Save the access token to the keychain for " << userId;
-    QKeychain::WritePasswordJob job(qAppName());
-    job.setAutoDelete(false);
-    job.setKey(userId);
-    job.setBinaryData(accessToken);
-    QEventLoop loop;
-    QKeychain::WritePasswordJob::connect(&job, &QKeychain::Job::finished, &loop, &QEventLoop::quit);
-    job.start();
-    loop.exec();
-
-    if (job.error()) {
-        qWarning() << "Could not save access token to the keychain: " << qPrintable(job.errorString());
-        return false;
-    }
-    return true;
+    auto job = new QKeychain::WritePasswordJob(qAppName());
+    job->setAutoDelete(true);
+    job->setKey(userId);
+    job->setBinaryData(accessToken);
+    connect(job, &QKeychain::WritePasswordJob::finished, this, [job]() {
+        if (job->error()) {
+            qWarning() << "Could not save access token to the keychain: " << qPrintable(job->errorString());
+        }
+    });
+    job->start();
 }
 
 bool Controller::supportSystemTray() const
