@@ -4,10 +4,11 @@
 #pragma once
 
 #include <Quotient/jobs/basejob.h>
+
 #include <Quotient/omittable.h>
 
 class NeochatChangePasswordJob : public Quotient::BaseJob
 {
 public:
-    explicit NeochatChangePasswordJob(const QString &newPassword, bool logoutDevices, const Quotient::Omittable<QJsonObject> &auth = Quotient::none);
+    explicit NeochatChangePasswordJob(const QString &newPassword, bool logoutDevices, const Quotient::Omittable<QJsonObject> &auth = {});
 };
