@@ -9,5 +9,5 @@
 class NeoChatDeactivateAccountJob : public Quotient::BaseJob
 {
 public:
-    explicit NeoChatDeactivateAccountJob(const Quotient::Omittable<QJsonObject> &auth = Quotient::none);
+    explicit NeoChatDeactivateAccountJob(const Quotient::Omittable<QJsonObject> &auth = {});
 };
