@@ -5,6 +5,7 @@
 #include <QIcon>
 #include <QNetworkDiskCache>
 #include <QNetworkProxyFactory>
+#include <QNetworkReply>
 #include <QObject>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
@@ -12,6 +13,7 @@
 #include <QQuickStyle>
 #include <QQuickWindow>
 #include <QtQml/QQmlExtensionPlugin>
+#include <Quotient/connection.h>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -46,11 +48,10 @@
 #include "colorschemer.h"
 #include "controller.h"
 #include "logger.h"
-#include "matriximageprovider.h"
 #include "neochatconfig.h"
 #include "roommanager.h"
-#include "windowcontroller.h"
 #include "sharehandler.h"
+#include "windowcontroller.h"
 
 #ifdef HAVE_RUNNER
 #include "runner.h"
@@ -174,6 +175,7 @@ int main(int argc, char *argv[])
     initLogging();
 
     Connection::setEncryptionDefault(true);
+    Connection::setDirectChatEncryptionDefault(true);
 
 #ifdef NEOCHAT_FLATPAK
     // Copy over the included FontConfig configuration to the
@@ -236,6 +238,7 @@ int main(int argc, char *argv[])
     Q_IMPORT_QML_PLUGIN(org_kde_neochat_timelinePlugin)
     Q_IMPORT_QML_PLUGIN(org_kde_neochat_devtoolsPlugin)
     Q_IMPORT_QML_PLUGIN(org_kde_neochat_loginPlugin)
+    Q_IMPORT_QML_PLUGIN(org_kde_neochat_chatbarPlugin)
 
     qml_register_types_org_kde_neochat();
 
@@ -285,7 +288,6 @@ int main(int argc, char *argv[])
         ShareHandler::instance().setText(parser.value(shareOption));
     }
 
-    engine.addImageProvider(QLatin1String("mxc"), MatrixImageProvider::create(&engine, &engine));
     engine.addImageProvider(QLatin1String("blurhash"), new BlurhashImageProvider);
 
     engine.loadFromModule("org.kde.neochat", "Main");
