@@ -1,6 +1,8 @@
 // SPDX-FileCopyrightText: 2023 James Graham <james.h.graham@protonmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
+#include <QPointer>
+
 #include <Quotient/csapi/space_hierarchy.h>
 #include <Quotient/events/stateevent.h>
 
@@ -33,14 +35,15 @@ public:
                            bool worldReadable = {},
                            bool isSpace = {},
                            Quotient::StateEvents childStates = {});
-    ~SpaceTreeItem();
+
+    bool operator==(const SpaceTreeItem &other) const;
 
     /**
      * @brief Return the child at the given row number.
      *
      * Nullptr is returned if there is no child at the given row number.
      */
-    SpaceTreeItem *child(int number);
+    SpaceTreeItem *child(int row);
 
     /**
      * @brief The number of children this item has.
@@ -48,9 +51,9 @@ public:
     int childCount() const;
 
     /**
-     * @brief Insert the given child at the given row number.
+     * @brief Insert the given child.
      */
-    bool insertChild(int row, SpaceTreeItem *newChild);
+    bool insertChild(std::unique_ptr<SpaceTreeItem> newChild);
 
     /**
      * @brief Remove the child at the given row number.
@@ -125,6 +128,11 @@ public:
      */
     bool isSpace() const;
 
+    /**
+     * @brief Return the m.space.child stripped state Json for the given child.
+     */
+    QJsonObject childState(const SpaceTreeItem *child) const;
+
     /**
      * @brief Return the m.space.child state event content for the given child.
      */
@@ -143,8 +151,8 @@ public:
     bool isSuggested() const;
 
 private:
-    NeoChatConnection *m_connection;
-    QList<SpaceTreeItem *> m_children;
+    QPointer<NeoChatConnection> m_connection;
+    std::vector<std::unique_ptr<SpaceTreeItem>> m_children;
     SpaceTreeItem *m_parentItem;
 
     QString m_id;
