@@ -12,6 +12,7 @@
 #include "linkpreviewer.h"
 #include "neochatconfig.h"
 #include "neochatroom.h"
+#include "notificationsmanager.h"
 #include "roommanager.h"
 #include "spacehierarchycache.h"
 
@@ -24,6 +25,7 @@
 
 #include <Quotient/csapi/content-repo.h>
 #include <Quotient/csapi/profile.h>
+#include <Quotient/csapi/versions.h>
 #include <Quotient/database.h>
 #include <Quotient/jobs/downloadfilejob.h>
 #include <Quotient/qt_connection_util.h>
@@ -60,9 +62,16 @@ void NeoChatConnection::connectSignals()
         if (type == QLatin1String("org.kde.neochat.account_label")) {
             Q_EMIT labelChanged();
         }
+        if (type == QLatin1String("m.identity_server")) {
+            Q_EMIT identityServerChanged();
+        }
     });
     connect(this, &NeoChatConnection::syncDone, this, [this] {
         setIsOnline(true);
+
+        connect(this, &NeoChatConnection::syncDone, this, [this]() {
+            NotificationsManager::instance().handleNotifications(this);
+        });
     });
     connect(this, &NeoChatConnection::networkError, this, [this]() {
         setIsOnline(false);
@@ -124,6 +133,21 @@ void NeoChatConnection::connectSignals()
         Q_EMIT homeNotificationsChanged();
         Q_EMIT homeHaveHighlightNotificationsChanged();
     });
+
+    // Fetch unstable features
+    // TODO: Expose unstableFeatures() in libQuotient
+    connect(
+        this,
+        &Connection::connected,
+        this,
+        [this] {
+            auto job = callApi<GetVersionsJob>(BackgroundRequest);
+            connect(job, &GetVersionsJob::success, this, [this, job] {
+                m_canCheckMutualRooms = job->unstableFeatures().contains("uk.half-shot.msc2666.query_mutual_rooms"_ls);
+                Q_EMIT canCheckMutualRoomsChanged();
+            });
+        },
+        Qt::SingleShotConnection);
 }
 
 int NeoChatConnection::badgeNotificationCount() const
@@ -192,6 +216,11 @@ QVariantList NeoChatConnection::getSupportedRoomVersions() const
     return supportedRoomVersions;
 }
 
+bool NeoChatConnection::canCheckMutualRooms() const
+{
+    return m_canCheckMutualRooms;
+}
+
 void NeoChatConnection::changePassword(const QString &currentPassword, const QString &newPassword)
 {
     auto job = callApi<NeochatChangePasswordJob>(newPassword, false);
@@ -256,6 +285,41 @@ ThreePIdModel *NeoChatConnection::threePIdModel() const
     return m_threePIdModel;
 }
 
+bool NeoChatConnection::hasIdentityServer() const
+{
+    if (!hasAccountData(QLatin1String("m.identity_server"))) {
+        return false;
+    }
+
+    const auto url = accountData(QLatin1String("m.identity_server"))->contentPart<QUrl>(QLatin1String("base_url"));
+    if (!url.isEmpty()) {
+        return true;
+    }
+    return false;
+}
+
+QUrl NeoChatConnection::identityServer() const
+{
+    if (!hasAccountData(QLatin1String("m.identity_server"))) {
+        return {};
+    }
+
+    const auto url = accountData(QLatin1String("m.identity_server"))->contentPart<QUrl>(QLatin1String("base_url"));
+    if (!url.isEmpty()) {
+        return url;
+    }
+    return {};
+}
+
+QString NeoChatConnection::identityServerUIString() const
+{
+    if (!hasIdentityServer()) {
+        return i18nc("@info", "No identity server configured");
+    }
+
+    return identityServer().toString();
+}
+
 void NeoChatConnection::createRoom(const QString &name, const QString &topic, const QString &parent, bool setChildParent)
 {
     QList<CreateRoomJob::StateEvent> initialStateEvents;
@@ -283,9 +347,14 @@ void NeoChatConnection::createRoom(const QString &name, const QString &topic, co
     connect(job, &CreateRoomJob::failure, this, [job] {
         Q_EMIT Controller::instance().errorOccured(i18n("Room creation failed: %1", job->errorString()), {});
     });
-    connectSingleShot(this, &Connection::newRoom, this, [](Room *room) {
-        RoomManager::instance().resolveResource(room->id());
-    });
+    connect(
+        this,
+        &Connection::newRoom,
+        this,
+        [](Room *room) {
+            RoomManager::instance().resolveResource(room->id());
+        },
+        Qt::SingleShotConnection);
 }
 
 void NeoChatConnection::createSpace(const QString &name, const QString &topic, const QString &parent, bool setChildParent)
@@ -315,9 +384,14 @@ void NeoChatConnection::createSpace(const QString &name, const QString &topic, c
     connect(job, &CreateRoomJob::failure, this, [job] {
         Q_EMIT Controller::instance().errorOccured(i18n("Space creation failed: %1", job->errorString()), {});
     });
-    connectSingleShot(this, &Connection::newRoom, this, [](Room *room) {
-        RoomManager::instance().resolveResource(room->id());
-    });
+    connect(
+        this,
+        &Connection::newRoom,
+        this,
+        [](Room *room) {
+            RoomManager::instance().resolveResource(room->id());
+        },
+        Qt::SingleShotConnection);
 }
 
 bool NeoChatConnection::directChatExists(Quotient::User *user)
@@ -345,10 +419,7 @@ void NeoChatConnection::openOrCreateDirectChat(User *user)
             return;
         }
     }
-    requestDirectChat(user);
-    connectSingleShot(this, &Connection::directChatAvailable, this, [=](auto room) {
-        room->activateEncryption();
-    });
+    requestDirectChat(user->id());
 }
 
 qsizetype NeoChatConnection::directChatNotifications() const
