@@ -12,6 +12,7 @@
 #include <QVariantMap>
 
 #include <Quotient/csapi/registration.h>
+#include <Quotient/omittable.h>
 
 #include <Quotient/jobs/basejob.h>
 #include <Quotient/util.h>
@@ -27,12 +28,12 @@ class NeoChatRegisterJob : public Quotient::BaseJob
 {
 public:
     explicit NeoChatRegisterJob(const QString &kind = QStringLiteral("user"),
-                                const Quotient::Omittable<QJsonObject> &auth = Quotient::none,
+                                const Quotient::Omittable<QJsonObject> &auth = {},
                                 const QString &username = {},
                                 const QString &password = {},
                                 const QString &deviceId = {},
                                 const QString &initialDeviceDisplayName = {},
-                                Quotient::Omittable<bool> inhibitLogin = Quotient::none);
+                                Quotient::Omittable<bool> inhibitLogin = {});
 
     QString userId() const
     {
