@@ -16,6 +16,7 @@
 #include "urlhelper.h"
 
 #include <KLocalizedString>
+#include <KRuntimePlatform>
 #include <QDesktopServices>
 #include <QQuickTextDocument>
 #include <QStandardPaths>
@@ -239,6 +240,12 @@ void RoomManager::loadInitialRoom()
         resolveResource(m_arg);
     }
 
+    const auto runtimePlatform = KRuntimePlatform::runtimePlatform();
+    if (runtimePlatform.contains(QStringLiteral("phone")) || runtimePlatform.contains(QStringLiteral("handset"))) {
+        // We don't want to open a room on startup on mobile
+        return;
+    }
+
     if (m_currentRoom) {
         // we opened a room with the arg parsing already
         return;
@@ -350,7 +357,11 @@ void RoomManager::joinRoom(Quotient::Connection *account, const QString &roomAli
 
 void RoomManager::knockRoom(NeoChatConnection *account, const QString &roomAliasOrId, const QString &reason, const QStringList &viaServers)
 {
+#if Quotient_VERSION_MINOR > 8
+    auto job = account->callApi<KnockRoomJob>(roomAliasOrId, viaServers, viaServers, reason);
+#else
     auto job = account->callApi<KnockRoomJob>(roomAliasOrId, viaServers, reason);
+#endif
     // Upon completion, ensure a room object is created in case it hasn't come
     // with a sync yet. If the room object is not there, provideRoom() will
     // create it in Join state. finished() is used here instead of success()
