@@ -3,13 +3,14 @@
 
 #include "spacehierarchycache.h"
 
+#include <Quotient/csapi/space_hierarchy.h>
 #include <Quotient/qt_connection_util.h>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 
+#include "neochatconnection.h"
 #include "neochatroom.h"
-#include "neochatroomtype.h"
 #include "roomlistmodel.h"
 
 using namespace Quotient;
@@ -31,11 +32,16 @@ void SpaceHierarchyCache::cacheSpaceHierarchy()
         if (neoChatRoom->isSpace()) {
             populateSpaceHierarchy(neoChatRoom->id());
         } else {
-            connectSingleShot(neoChatRoom, &Room::baseStateLoaded, neoChatRoom, [this, neoChatRoom]() {
-                if (neoChatRoom->isSpace()) {
-                    populateSpaceHierarchy(neoChatRoom->id());
-                }
-            });
+            connect(
+                neoChatRoom,
+                &Room::baseStateLoaded,
+                neoChatRoom,
+                [this, neoChatRoom]() {
+                    if (neoChatRoom->isSpace()) {
+                        populateSpaceHierarchy(neoChatRoom->id());
+                    }
+                },
+                Qt::SingleShotConnection);
         }
 
         connect(neoChatRoom, &NeoChatRoom::unreadStatsChanged, this, [this, neoChatRoom]() {
@@ -56,7 +62,7 @@ void SpaceHierarchyCache::populateSpaceHierarchy(const QString &spaceId)
     }
 
     m_nextBatchTokens[spaceId] = QString();
-    auto job = m_connection->callApi<GetSpaceHierarchyJob>(spaceId, none, none, none, *m_nextBatchTokens[spaceId]);
+    auto job = m_connection->callApi<GetSpaceHierarchyJob>(spaceId, std::nullopt, std::nullopt, std::nullopt, *m_nextBatchTokens[spaceId]);
     auto group = KConfigGroup(KSharedConfig::openStateConfig("SpaceHierarchy"_ls), "Cache"_ls);
     m_spaceHierarchy.insert(spaceId, group.readEntry(spaceId, QStringList()));
 
@@ -85,7 +91,7 @@ void SpaceHierarchyCache::addBatch(const QString &spaceId, Quotient::GetSpaceHie
     const auto nextBatchToken = job->nextBatch();
     if (!nextBatchToken.isEmpty() && nextBatchToken != *m_nextBatchTokens[spaceId]) {
         *m_nextBatchTokens[spaceId] = nextBatchToken;
-        auto nextJob = m_connection->callApi<GetSpaceHierarchyJob>(spaceId, none, none, none, *m_nextBatchTokens[spaceId]);
+        auto nextJob = m_connection->callApi<GetSpaceHierarchyJob>(spaceId, std::nullopt, std::nullopt, std::nullopt, *m_nextBatchTokens[spaceId]);
         connect(nextJob, &BaseJob::success, this, [this, nextJob, spaceId]() {
             addBatch(spaceId, nextJob);
         });
@@ -96,12 +102,17 @@ void SpaceHierarchyCache::addBatch(const QString &spaceId, Quotient::GetSpaceHie
 
 void SpaceHierarchyCache::addSpaceToHierarchy(Quotient::Room *room)
 {
-    connectSingleShot(room, &Quotient::Room::baseStateLoaded, this, [this, room]() {
-        const auto neoChatRoom = static_cast<NeoChatRoom *>(room);
-        if (neoChatRoom->isSpace()) {
-            populateSpaceHierarchy(neoChatRoom->id());
-        }
-    });
+    connect(
+        room,
+        &Quotient::Room::baseStateLoaded,
+        this,
+        [this, room]() {
+            const auto neoChatRoom = static_cast<NeoChatRoom *>(room);
+            if (neoChatRoom->isSpace()) {
+                populateSpaceHierarchy(neoChatRoom->id());
+            }
+        },
+        Qt::SingleShotConnection);
 }
 
 void SpaceHierarchyCache::removeSpaceFromHierarchy(Quotient::Room *room)
