@@ -389,7 +389,7 @@ QString TextHandler::stripBlockTags(QString string, const QString &tagType) cons
 
 QString TextHandler::getTagType(const QString &tagToken) const
 {
-    if (tagToken.isEmpty()) {
+    if (tagToken.isEmpty() || tagToken.length() < 2) {
         return QString();
     }
     const int tagTypeStart = tagToken[1] == u'/' ? 2 : 1;
@@ -691,9 +691,9 @@ QString TextHandler::emoteString(const NeoChatRoom *room, const Quotient::RoomEv
     }
 
     auto e = eventCast<const Quotient::RoomMessageEvent>(event);
-    auto author = room->user(e->senderId());
-    return QStringLiteral("* <a href=\"https://matrix.to/#/") + e->senderId() + QStringLiteral("\" style=\"color:") + Utils::getUserColor(author->hueF()).name()
-        + QStringLiteral("\">") + author->displayname(room) + QStringLiteral("</a> ");
+    auto author = room->member(e->senderId());
+    return QStringLiteral("* <a href=\"https://matrix.to/#/") + e->senderId() + QStringLiteral("\" style=\"color:") + author.color().name()
+        + QStringLiteral("\">") + author.htmlSafeDisplayName() + QStringLiteral("</a> ");
 }
 
 QString TextHandler::convertCodeLanguageString(const QString &languageString)
